Name:           imagej
Version:        1.54m
Release:        %mkrel 1
Summary:        Image Processing and Analysis in Java

License:        Public Domain
Group:          Sciences/Computer science
URL:            https://imagej.net/ij/index.html
Source0:        https://imagej.net/ij/download/src/ij%(echo '%{version}' | tr -d .)-src.zip
Source1:        imagej.desktop
Source2:        https://rsbweb.nih.gov/ij/macros/macros.zip
Source3:        https://rsb.info.nih.gov/ij/download/linux/unix-script.txt
Source4:        imagej.png

BuildArch:      noarch

# Do not copy class files.
Patch0:         imagej-1.54g-do-not-copy-class-files.patch
# Modify imagej.sh (as intended by upstream) for Fedora compatibility.
Patch1:         imagej-1.53r-unix-script.patch
# Set javac source / target version to 1.8 to fix building with Java 11.
Patch2:         imagej-1.53r-source-target-version.patch

BuildRequires:  ant
BuildRequires:  desktop-file-utils

BuildRequires:  jpackage-utils
BuildRequires:  java-devel

Requires:       jpackage-utils
# Require java-devel, not only java, for plugins build
Requires:       java-devel

# We no longer package javadoc documentation because it has guidelines issues
# pertaining to bundled and pre-minified JavaScript and CSS.  See
# https://bugzilla.redhat.com/show_bug.cgi?id=2006555 and the linked
# “packaging” mailing list discussion for similar issues in documentation
# generated by Sphinx and Doxygen.
Obsoletes:      imagej-javadoc < 1.53r-1

%description
ImageJ is a public domain Java image processing program. It can display, edit,
analyze a wide variety of image data, including image sequences. Imagej can be
used for quantitative analysis of engineering and scientific image data.


%prep
%autosetup -c -N
unzip -qq -u '%{SOURCE2}'
cp -p '%{SOURCE3}' ./imagej.sh

# Erase binary and useless files
rm -rvf macros/.FBC* macros/build.xml __MACOSX
# Strip out any bundled pre-compiled class or jar files:
find . \( -name '*.class' -o -name '*.jar' \) -print -delete
# Fix permissions
find macros -type d -exec chmod -v 0755 '{}' '+'
find macros -type f -exec chmod -v 0644 '{}' '+'

%autopatch -p1
# Replace placeholders in our patched unix-script.txt/imagej.sh.
sed -r -i \
    -e 's#@JAVADIR@#%{_javadir}#' \
    -e 's#@PKGDATADIR@#%{_datadir}/imagej#' \
    imagej.sh

# Make sure the upstream version number is set correctly, and use the initial
# numeric <pkgrel> field of the Release as the BUILD.
%global pkgrel %(echo '%{release}' | sed -r 's/[^[:digit:]].*$//')
sed -r -i \
    -e 's/(public static final String VERSION = )"[^"]+";/\1"%{version}";/' \
    -e 's/(public static final String BUILD = )"[^"]+";/\1"%{pkgrel}";/' \
    source/ij/ImageJ.java


%build
cd source
ant build
cd ..


%install
# install jar
install -p -m 0644 -D source/ij.jar '%{buildroot}%{_javadir}/imagej.jar'

# install icon
install -D -p -m 0644 -t '%{buildroot}%{_datadir}/pixmaps' '%{SOURCE4}'

# install data files and macros
install -D -p -m 0644 -t '%{buildroot}%{_datadir}/imagej' \
    source/build/about.jpg source/build/IJ_Props.txt
cp -rvp macros '%{buildroot}%{_datadir}/imagej/'

# install directories for luts and plugins
install -d '%{buildroot}%{_datadir}/imagej/luts' \
    '%{buildroot}%{_datadir}/imagej/plugins'
# install -p -m 0644 source/plugins/JavaScriptEvaluator.source \
#    '%%{buildroot}%%{_datadir}/imagej/plugins/JavaScriptEvaluator.java'

# install script
install -D -p imagej.sh '%{buildroot}%{_bindir}/imagej'

# desktop file
desktop-file-install --vendor=''                     \
       --dir=%{buildroot}%{_datadir}/applications/   \
       %{SOURCE1}


%files
%doc source/aREADME.txt source/release-notes.html

%{_javadir}/imagej.jar

%{_datadir}/imagej/
%{_datadir}/applications/imagej.desktop
%{_datadir}/pixmaps/imagej.png

%{_bindir}/imagej



%changelog
* Mon Dec 30 2024 daviddavid <daviddavid> 1.54m-1.mga10
+ Revision: 2131603
- new version: 1.54m

* Tue Dec 03 2024 daviddavid <daviddavid> 1.54k-1.mga10
+ Revision: 2120774
- new version: 1.54k

* Sun Jul 07 2024 daviddavid <daviddavid> 1.54j-1.mga10
+ Revision: 2080167
- new version: 1.54j

* Mon May 27 2024 daviddavid <daviddavid> 1.54i-1.mga10
+ Revision: 2067891
- new version: 1.54i

* Thu Feb 15 2024 daviddavid <daviddavid> 1.54h-1.mga10
+ Revision: 2041323
- new version: 1.54h

* Thu Oct 26 2023 daviddavid <daviddavid> 1.54g-1.mga10
+ Revision: 2001989
- new version: 1.54g

* Mon Sep 04 2023 daviddavid <daviddavid> 1.54f-1.mga10
+ Revision: 1983943
- new version: 1.54f

* Tue Jan 03 2023 daviddavid <daviddavid> 1.53v-1.mga9
+ Revision: 1929515
- new version: 1.53v

* Mon Sep 19 2022 neoclust <neoclust> 1.53r-1.mga9
+ Revision: 1890514
- New version 1.53r

* Sat Mar 26 2022 umeabot <umeabot> 1.53d-3.mga9
+ Revision: 1828797
- Mageia 9 Mass Rebuild

* Fri Sep 04 2020 daviddavid <daviddavid> 1.53d-2.mga8
+ Revision: 1621538
- fix imagej wrapper (the program that starts the Image GUI in Mageia)
  for Java version 10 or later. The wrapper made use of the -d64 and -d32
  options which have been deprecated for a while, did nothing, and were
  removed in OpenJDK 10.  See "Removal of Java Launcher's Data Model Options
  -d32 and -d64" on the openjdk-10 release notes (mga#27225)

* Sun Aug 30 2020 daviddavid <daviddavid> 1.53d-1.mga8
+ Revision: 1620109
- new version: 1.53d

* Sun Aug 30 2020 daviddavid <daviddavid> 1.52k-3.mga8
+ Revision: 1619997
- Rebuilt for JDK-11

* Fri Feb 14 2020 umeabot <umeabot> 1.52k-2.mga8
+ Revision: 1522870
- Mageia 8 Mass Rebuild

* Sun Feb 10 2019 daviddavid <daviddavid> 1.52k-1.mga7
+ Revision: 1364787
- new version: 1.52k

* Sun Feb 10 2019 daviddavid <daviddavid> 1.52j-1.mga7
+ Revision: 1364782
- new version: 1.52j

* Thu Sep 20 2018 umeabot <umeabot> 1.51w-2.mga7
+ Revision: 1278870
- Mageia 7 Mass Rebuild

* Tue Apr 03 2018 kekepower <kekepower> 1.51w-1.mga7
+ Revision: 1214811
- Update to version 1.51w

* Wed May 11 2016 daviddavid <daviddavid> 1.50h-1.mga6
+ Revision: 1012902
- Update to upstream release 1.50h

* Sun Feb 28 2016 umeabot <umeabot> 1.48e-2.mga6
+ Revision: 980464
- Mageia 6 Mass Rebuild

* Fri Jul 03 2015 daviddavid <daviddavid> 1.48e-1.mga6
+ Revision: 849716
- new version: 1.48e
- rename Patches
- add a png icon
- update desktop file
- update file list
- fix Group

* Wed Oct 15 2014 umeabot <umeabot> 1.45b-5.mga5
+ Revision: 747502
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.45b-4.mga5
+ Revision: 680484
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.45b-3.mga4
+ Revision: 505964
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 1.45b-2.mga3
+ Revision: 354289
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 20 2011 barjac <barjac> 1.45b-1.mga2
+ Revision: 169686
- Change to desktop file and spec
- imported package imagej


* Sat Nov 19 2011 Barry Jackson <zen25000[at]zen.co.uk> 1.45b-1.mga2
- Import imagej

* Wed Mar 09 2011 StM-CM-)phane TM-CM-)letchM-CM-)a <steletch@mandriva.org> 1.45b-2mdv2011.0
+ Revision: 643127
- Fix group tag for ImageJ and ImageJ-docs
- Add missing BR
- Fix group tag
- Update Mandriva specific informations
- Initial imageJ Mandriva package adaptated from Fedora package

